@@ -8,11 +8,12 @@ import contextlib
 import shutil
 import time
 import tempfile
+import tarfile
 
-# the code in this file as originally inspired by similar code for R
+# the code in this file was originally inspired by similar code for R
 # https://github.com/beanumber/abdwr3edata/blob/main/R/parse_retrosheet_pbp.R
-
 # TODO: add gamelog functionality that mirrors events? (allstar, postseason, use helper functions)
+# TODO: add cwevent_dir to all load functions (and pass to download functions)?
 
 
 @contextlib.contextmanager
@@ -27,13 +28,10 @@ def _pushd(new_dir):
 
 @contextlib.contextmanager
 def prepend_path(dir):
-    if dir is None:
-        yield
-        return
     abs_dir = os.path.abspath(dir)
-    cwd_dir = os.getcwd()  # Add the user's working directory
+    cwd_dir = os.getcwd()
     old_path = os.environ.get("PATH", "")
-    new_path = os.pathsep.join([abs_dir, cwd_dir, old_path])
+    new_path = os.pathsep.join([abs_dir, cwd_dir, "/usr/local/bin", old_path])
     os.environ["PATH"] = new_path
     try:
         yield
@@ -45,7 +43,6 @@ def prepend_path(dir):
 # names originally from:
 # https://github.com/maxtoki/baseball_R/blob/master/data/game_log_header.csv
 # changed HomeRunsScore to HomeRunsScored which seems to have been a typo
-# TODO: Visiting -> Visitor for consistency? Use just "Visit" instead for concision?
 gamelogs_header = [
     "Date",
     "DoubleHeader",
@@ -247,13 +244,14 @@ def _download_and_unzip(url, zipped_file, extract_to, retries=3, delay=2):
                 ) from e
 
 
+# TODO: set a default for cwevent_dir? or if None, use working dir?
 def download_events(
     start_year,
     end_year=None,
     postseason=False,
     allstar=False,
     data_dir="retrosheet",
-    cwevent_dir=None,
+    cwevent_dir="chadwick",
 ):
 
     if postseason and allstar:
@@ -311,6 +309,10 @@ def download_events(
             # obtain zipped events from retrosheet website and decompress
             _download_and_unzip(url, zipped_file, temp_dir)
 
+            # try to use current directory if no cwevent_dir supplied
+            if cwevent_dir is None:
+                cwevent_dir = os.getcwd()
+
             # allow user to specify directory containing cwevent and temporarily add it to PATH
             with prepend_path(cwevent_dir):
 
@@ -477,3 +479,60 @@ def load_gamelogs(year, data_dir="retrosheet", force_download=False):
     if not os.path.exists(gamelogs_parquet) or force_download:
         download_gamelogs(year, data_dir=data_dir)
     return pd.read_parquet(gamelogs_parquet, engine="pyarrow")
+
+
+def download_chadwick(install_dir="chadwick"):
+    install_dir = os.path.join(os.getcwd(), install_dir)
+    os.makedirs(install_dir, exist_ok=True)
+    if os.name == "nt":
+        url = "https://github.com/chadwickbureau/chadwick/releases/download/v0.10.0/chadwick-0.10.0-win.zip"
+        filename = "chadwick-0.10.0-win.zip"
+        print(f"Downloading Chadwick tools to {install_dir}")
+    else:
+        url = "https://github.com/chadwickbureau/chadwick/releases/download/v0.10.0/chadwick-0.10.0.tar.gz"
+        filename = "chadwick-0.10.0.tar.gz"
+        print(f"This function currently only supports Windows.")
+        return None
+    with tempfile.TemporaryDirectory() as temp_dir:
+        archive_file = os.path.join(temp_dir, filename)
+        print(f"Downloading {url}")
+        r = requests.get(url, timeout=30)
+        r.raise_for_status()
+        with open(archive_file, "wb") as f:
+            f.write(r.content)
+        print(f"Extracting to {temp_dir}")
+        if filename.endswith(".zip"):
+            with zipfile.ZipFile(archive_file, "r") as zip_ref:
+                zip_ref.extractall(temp_dir)
+        elif filename.endswith(".tar.gz"):
+            with tarfile.open(archive_file, "r:gz") as tar_ref:
+                tar_ref.extractall(temp_dir, filter="data")
+        extracted_dirs = [
+            d
+            for d in os.listdir(temp_dir)
+            if os.path.isdir(os.path.join(temp_dir, d)) and not d.startswith(".")
+        ]
+        if extracted_dirs:
+            chadwick_dir = os.path.join(temp_dir, extracted_dirs[0])
+        else:
+            if os.name == "nt":
+                exe_files = [f for f in os.listdir(temp_dir) if f.endswith(".exe")]
+            else:
+                exe_files = None
+            if exe_files:
+                chadwick_dir = temp_dir
+            else:
+                raise RuntimeError("No Chadwick tools found in extracted archive")
+        for item in os.listdir(chadwick_dir):
+            if item.endswith((".zip", ".tar.gz")) or item.startswith("."):
+                continue
+            src = os.path.join(chadwick_dir, item)
+            dst = os.path.join(install_dir, item)
+            if os.path.isdir(src):
+                shutil.copytree(src, dst, dirs_exist_ok=True)
+            else:
+                shutil.copy2(src, dst)
+    print(f"Chadwick tools installed to: {install_dir}")
+    if os.name == "nt":
+        print(f"You can now use cwevent_dir='{install_dir}' in download_events().")
+    return install_dir
